==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/text/l10n/es_CL.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "New text file" : "Nuevo archivo de texto",
    "File not found" : "Archivo no encontrado",
    "Text" : "Texto",
    "Translate" : "Traducir",
    "Guest" : "Invitado",
    "you" : "tú",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Link" : "Ligas",
    "name" : "nombre",
    "Action" : "Acción",
    "Undo" : "Deshacer",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Formatting help" : "Ayuda de formato",
    "Select language" : "Selecciona el idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Upload" : "Cargar",
    "Edit" : "Editar",
    "Source code" : "Código fuente",
    "Choose" : "Seleccionar",
    "Info" : "Info",
    "Success" : "Éxito",
    "Warning" : "Advertencia"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.12.tar.bz2: nextcloud/apps/text/l10n/es_CL.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "New text file" : "Nuevo archivo de texto",
    "File not found" : "Archivo no encontrado",
    "Text" : "Texto",
    "Guest" : "Invitado",
    "you" : "tú",
    "Copy link" : "Copiar liga",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Link" : "Ligas",
    "name" : "nombre",
    "Action" : "Acción",
    "Undo" : "Deshacer",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Save" : "Guardar",
    "Formatting help" : "Ayuda de formato",
    "Translate" : "Traducir",
    "Select language" : "Selecciona el idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Upload" : "Cargar",
    "Edit" : "Editar",
    "Source code" : "Código fuente",
    "Choose" : "Seleccionar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
